@@ -1,8 +1,7 @@
 import logging
 from typing import Optional
 
-from django.contrib.auth import get_user_model
-from django.contrib.auth.models import Group
+from django.contrib.auth.models import AbstractUser, Group
 from django.db.models import QuerySet
 from guardian.shortcuts import get_objects_for_user
 from rest_framework import permissions
@@ -10,23 +9,21 @@ from rest_framework.exceptions import MethodNotAllowed
 from rest_framework.permissions import BasePermission, IsAuthenticated
 
 logger = logging.getLogger(__name__)
-
 update_methods = ("PUT", "PATCH")
-
-User = get_user_model()
-
 perm_group_manager = "auth.change_group"
 
 
-def get_group_manager_groups(user: User) -> QuerySet[Group]:
+def get_group_manager_groups(user: AbstractUser) -> QuerySet[Group]:
     return get_objects_for_user(user, perm_group_manager)
 
 
-def has_group_manager_groups(user: User) -> bool:
+def has_group_manager_groups(user: AbstractUser) -> bool:
     return get_group_manager_groups(user).exists()
 
 
-def has_group_manager_permission(user: User, group: Optional[Group] = None) -> bool:
+def has_group_manager_permission(
+    user: AbstractUser, group: Optional[Group] = None
+) -> bool:
     return user.has_perm(perm_group_manager, group)
 
 
@@ -66,7 +63,7 @@ class IsGroupManagerWrite(permissions.BasePermission):
         )
 
 
-def is_staff(user: User) -> bool:
+def is_staff(user: AbstractUser) -> bool:
     return user.is_staff or user.is_superuser
 
 
