@@ -18,7 +18,7 @@ class ProfileSerializer(serializers.ModelSerializer):
             "display_id",
         )
 
-    def get_affiliation_home(self, obj: Profile):  # pylint: disable=no-self-use
+    def get_affiliation_home(self, obj: Profile):
         if obj.affiliation:
             return ",".join(
                 sorted(
