@@ -1,6 +1,7 @@
 import logging
 
 from django.contrib.auth import get_user_model
+from django.contrib.auth.models import AbstractUser
 from rest_framework import serializers
 
 from ..permissions import has_group_manager_groups
@@ -30,14 +31,14 @@ class UserinfoSerializer(serializers.ModelSerializer):
             "id",
         )
 
-    def get_ip_address(self, _: User):
+    def get_ip_address(self, _: AbstractUser):
         request = self.context["request"]
         x_forwarded_for = request.META.get("HTTP_X_FORWARDED_FOR")
         if x_forwarded_for:
             return x_forwarded_for.split(",")[0]
         return request.META.get("REMOTE_ADDR")
 
-    def get_permissions(self, _: User):
+    def get_permissions(self, _: AbstractUser):
         request = self.context["request"]
         return {
             "staff": request.user.is_staff,
