@@ -22,7 +22,7 @@ class ProfileFactory(factory.django.DjangoModelFactory):
     class Meta:
         model = Profile
 
-    affiliation = factory.Faker("company")
+    affiliation = "member@foo.edu,member@bar.org,staff@bar.org"
 
 
 @factory.django.mute_signals(signals.post_save)
